@@ -66,6 +66,23 @@ class MediaCategoryViewController: UICollectionViewController, UISearchBarDelega
         return actionSheet
     }()
 
+
+    private lazy var mediaOptionButton: UIButton = {
+        let button = UIButton(frame: CGRect(x: 0, y: 0, width: 44, height: 44))
+        button.tintColor = PresentationTheme.current.colors.orangeUI
+//        button.setImage(UIImage(named: "renderer"), for: .normal)
+//        button.setImage(UIImage(named: "rendererFull"), for: .selected)
+//        button.addTarget(self, action: #selector(displayActionSheet), for: .touchUpInside)
+        button.backgroundColor = .magenta
+        button.accessibilityLabel = NSLocalizedString("BUTTON_RENDERER", comment: "")
+        button.accessibilityHint = NSLocalizedString("BUTTON_RENDERER_HINT", comment: "")
+
+        button.layer.cornerRadius = 22
+        button.layer.masksToBounds = true
+        button.translatesAutoresizingMaskIntoConstraints = false
+        return button
+    }()
+
     private lazy var sortBarButton: UIBarButtonItem = {
         return UIBarButtonItem(customView: setupSortButton())
     }()
@@ -191,6 +208,10 @@ class MediaCategoryViewController: UICollectionViewController, UISearchBarDelega
         setupCollectionView()
         setupSearchBar()
         _ = (MLMediaLibrary.sharedMediaLibrary() as! MLMediaLibrary).libraryDidAppear()
+        self.view.addSubview(mediaOptionButton)
+        mediaOptionButton.leadingAnchor.constraint(equalTo: view.leadingAnchor, constant: 20).isActive = true
+        mediaOptionButton.bottomAnchor.constraint(equalTo: view.bottomAnchor, constant: -20).isActive = true
+        mediaOptionButton.widthAnchor.constraint(equalToConstant: 44).isActive = true
     }
 
     override func viewWillAppear(_ animated: Bool) {
